@@ -37,6 +37,7 @@ const TemplatesScriptsManager = imports.templatesScriptsManager;
 const Thumbnails = imports.thumbnails;
 const FileItemMenu = imports.fileItemMenu;
 const AutoAr = imports.autoAr;
+const SignalManager = imports.signalManager;
 
 const Gettext = imports.gettext.domain('ding');
 
@@ -394,9 +395,10 @@ var DesktopManager = class {
             let desktop = this._desktopList[desktopIndex];
             let desktopName;
             if (this._asDesktop) {
-                desktopName = `@!${desktop.x},${desktop.y};BDHF`;
+                // this name must match the one used in emulateX11WindowType
+                desktopName = `Desktop Icons ${desktop.monitorIndex + 1}`;
             } else {
-                desktopName = `DING ${desktopIndex}`;
+                desktopName = `DING ${desktop.monitorIndex + 1}`;
             }
             this._desktops.push(new DesktopGrid.DesktopGrid(this, desktopName, desktop, this._asDesktop, this._premultiplied));
         }
@@ -1007,12 +1009,13 @@ var DesktopManager = class {
         this._findFileTextArea = new Gtk.Entry();
         contentArea.pack_start(this._findFileTextArea, true, true, 5);
         contentArea = undefined;
-        this._findFileTextArea.connect('activate', () => {
+        this._findFileSignalManager = new SignalManager.SignalManager();
+        this._findFileSignalManager.connectSignal(this._findFileTextArea, 'activate', () => {
             if (this._findFileButton.sensitive) {
                 this._findFileWindow.response(Gtk.ResponseType.OK);
             }
         });
-        this._findFileTextArea.connect('changed', () => {
+        this._findFileSignalManager.connectSignal(this._findFileTextArea, 'changed', () => {
             let context = this._findFileTextArea.get_style_context();
             if (this.scanForFiles(this._findFileTextArea.text, true)) {
                 this._findFileButton.sensitive = true;
@@ -1036,13 +1039,14 @@ var DesktopManager = class {
             this.scanForFiles(null);
         }
         this._findFileWindow.show_all();
-        this._findFileWindow.connect('close', () => {
+        this._findFileSignalManager.connectSignal(this._findFileWindow, 'close', () => {
             this._findFileWindow.response(Gtk.ResponseType.CANCEL);
         });
-        this._findFileWindow.connect('response', (actor, retval) => {
+        this._findFileSignalManager.connectSignal(this._findFileWindow, 'response', (actor, retval) => {
             if (retval == Gtk.ResponseType.CANCEL) {
                 this.unselectAll();
             }
+            this._findFileSignalManager.disconnectAllSignals();
             this._findFileWindow.destroy();
             this._findFileWindow = null;
         });
@@ -1110,7 +1114,7 @@ var DesktopManager = class {
 
         this._changeBackgroundMenuItem = new Gtk.MenuItem({label: _('Change Background…')});
         this._changeBackgroundMenuItem.connect('activate', () => {
-            let desktopFile = Gio.DesktopAppInfo.new('gnome-background-panel.desktop');
+            const desktopFile = Gio.DesktopAppInfo.new('gnome-background-panel.desktop');
             const context = Gdk.Display.get_default().get_app_launch_context();
             context.set_timestamp(Gtk.get_current_event_time());
             desktopFile.launch([], context);
@@ -1134,7 +1138,7 @@ var DesktopManager = class {
 
         this._displaySettingsMenuItem = new Gtk.MenuItem({label: _('Display Settings')});
         this._displaySettingsMenuItem.connect('activate', () => {
-            let desktopFile = Gio.DesktopAppInfo.new('gnome-display-panel.desktop');
+            const desktopFile = Gio.DesktopAppInfo.new('gnome-display-panel.desktop');
             const context = Gdk.Display.get_default().get_app_launch_context();
             context.set_timestamp(Gtk.get_current_event_time());
             desktopFile.launch([], context);
